@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,14 +12,13 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "alsaclient.h"
-#include "alsaqueue.h"
-#include "alsaevent.h"
+#include <drumstick/alsaclient.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaevent.h>
 #include <QFile>
 #include <QRegExp>
 #include <QThread>
@@ -65,149 +64,6 @@
 
 namespace drumstick {
 
-/**
-@mainpage drumstick Documentation
-@author Copyright &copy; 2009-2014 Pedro López-Cabanillas &lt;plcl AT users.sf.net&gt;
-@date 2014-08-30
-@version 1.0.0
-
-This document is licensed under the Creative Commons Attribution-Share Alike 3.0 Unported License.
-To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/
-
-@section Abstract
-
-This is the reference documentation for drumstick. This library is a set of C++ MIDI related classes,
-using Qt5 objects, idioms and style.
-ALSA sequencer provides software support for MIDI technology on Linux.
-
-@see http://qt-project.org/doc/qt-5/index.html
-@see http://www.alsa-project.org/alsa-doc/alsa-lib/seq.html
-@see http://www.ics.com/design-patterns
-@see http://www.midi.org/aboutmidi/tutorials.php
-
-@section Disclaimer
-
-This document is a work in progress, in a very early state. It will be always in
-development. Please visit the drumstick web site to read the latest version.
-
-@see http://drumstick.sourceforge.net
-
-@section Introduction
-
-For an introduction to design and programming with C++ and Qt, see the book
-"An Introduction to Design Patterns in C++ with Qt" by by Alan Ezust and Paul
-Ezust. It is available published on dead trees, and also
-<a href="http://www.ics.com/design-patterns"> online</a>.
-
-Here is how a simple program playing a note-on MIDI message using drumstick
-looks like:
-
-@code
-#include <QApplication>
-#include <drumstick.h>
-
-int main(int argc, char **argv) {
-    QApplication app(argc, argv, false);
-
-    // create a client object on the heap
-    drumstick::MidiClient *client = new drumstick::MidiClient;
-    client->open();
-    client->setClientName( "MyClient" );
-
-    // create the port. Pointer is owned by the client instance
-    drumstick::MidiPort *port = client->createPort();
-    port->setPortName( "MyPort" );
-    port->setCapability( SND_SEQ_PORT_CAP_READ | SND_SEQ_PORT_CAP_SUBS_READ );
-    port->setPortType( SND_SEQ_PORT_TYPE_MIDI_GENERIC );
-    // subscribe the port to some other client:port
-    port->subscribeTo( "20:0" ); // or "name:port", like in "KMidimon:0"
-
-    // create an event object on the stack, to send a note on message
-    drumstick::NoteOnEvent ev( 0, 66, 100 ); // (channel, note number, velocity)
-    ev.setSource( port->getPortId() );
-    ev.setSubscribers();   // deliver to all the connected ports
-    ev.setDirect();        // not scheduled, deliver immediately
-    client->output( &ev ); // or outputDirect() if you prefer not buffered
-    client->drainOutput(); // flush the buffer
-
-    // close and clean
-    client->close();
-    delete client;
-    return 0;
-}
-@endcode
-
-There are more examples in the source tree, under the utils/ directory, and
-you can also see applications using this library, like kmetronome and kmidimon.
-
-@see http://kmetronome.sourceforge.net
-@see http://kmidimon.sourceforge.net
-@see http://kmid2.sourceforge.net
-@see http://vmpk.sourceforge.net
-
-@section Acknowledgments
-Parts of this documentation are copied from the ALSA library documentation,
-whose authors are:
-<ul>
-<li>Jaroslav Kysela &lt;perex AT perex.cz&gt;</li>
-<li>Abramo Bagnara &lt;abramo AT alsa-project.org&gt;</li>
-<li>Takashi Iwai &lt;tiwai AT suse.de&gt;</li>
-<li>Frank van de Pol &lt;fvdpol AT coil.demon.nl&gt;</li>
-</ul>
-
-@example drumgrid.cpp
-Simple drum patterns
-@include drumgrid.h
-
-@example dumpmid.cpp
-Print received sequencer events
-@include dumpmid.h
-
-@example playsmf.cpp
-SMF playback, command line interface program
-@include playsmf.h
-
-@example guiplayer.cpp
-SMF playback, graphic user interface program
-@include guiplayer.h
-
-@example buildsmf.cpp
-SMF output from scratch
-@include buildsmf.h
-
-@example dumpsmf.cpp
-SMF read and print
-@include dumpsmf.h
-
-@example dumpwrk.cpp
-Cakewalk WRK file parse and print
-@include dumpwrk.h
-
-@example dumpove.cpp
-Overture OVE file parse and print
-@include dumpove.h
-
-@example metronome.cpp
-Simple command line MIDI metronome
-@include metronome.h
-
-@example sysinfo.cpp
-Prints information about the ALSA sequencer subsystem
-
-@example testevents.cpp
-SequencerEvents test
-@include testevents.h
-
-@example timertest.cpp
-ALSA Timers test
-@include timertest.h
-
-@example vpiano.cpp
-A Virtual Piano Keyboard GUI application. See another one at http://vmpk.sf.net
-@include vpiano.h
-
-*/
-
 /**
  * @addtogroup ALSAClient
  * @{
@@ -1921,10 +1777,10 @@ MidiClient::SequencerInputThread::setRealtimePriority()
         if (reply.type() == QDBusMessage::ErrorMessage )
             qWarning() << "error returned by RealtimeKit.MakeThreadRealtime:"
                         << reply.errorMessage();
-#else
+#endif
+    } else {
         qWarning() << "pthread_setschedparam() failed, err="
                    << rt << ::strerror(rt);
-#endif
     }
 }
 
