@@ -1,6 +1,6 @@
 /*
     Standard MIDI File component
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -14,17 +14,16 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "qsmf.h"
 #include <limits>
 #include <QList>
 #include <QFile>
 #include <QDataStream>
 #include <QTextCodec>
+#include <drumstick/qsmf.h>
 
 /**
  * @file qsmf.cpp
@@ -65,8 +64,8 @@ public:
         m_Tracks(0),
         m_fileFormat(0),
         m_LastStatus(0),
-        m_codec(0),
-        m_IOStream(0)
+        m_codec(nullptr),
+        m_IOStream(nullptr)
     { }
 
     bool m_Interactive;     /**< file and track headers are not required */
@@ -126,7 +125,7 @@ bool QSmf::endOfSmf()
 quint8 QSmf::getByte()
 {
     quint8 b = 0;
-    if (!d->m_IOStream->atEnd())
+    if (!endOfSmf())
     {
         *d->m_IOStream >> b;
         d->m_ToBeRead--;
@@ -189,6 +188,10 @@ void QSmf::readHeader()
     {
         getByte();
     }
+    if (d->m_ToBeRead > 0)
+    {
+        SMFError("Unexpected end of input");
+    }
 }
 
 /**
@@ -234,13 +237,14 @@ void QSmf::readTrack()
 
     while (!endOfSmf() && (d->m_Interactive || d->m_ToBeRead > 0))
     {
+        lookfor = 0;
         if (d->m_Interactive)
         {
             d->m_CurrTime++;
         }
         else
         {
-            delta_ticks = readVarLen();
+            delta_ticks = unsigned(readVarLen());
             d->m_RevisedTime = d->m_CurrTime;
             d->m_CurrTime += delta_ticks;
             while (d->m_RevisedTime < d->m_CurrTime)
@@ -258,9 +262,9 @@ void QSmf::readTrack()
                         d->m_OldCurrTime = save_time;
                     }
                     delta_secs = ticksToSecs(d->m_RevisedTime - d->m_OldCurrTime,
-                            d->m_Division, save_tempo);
+                            quint16(d->m_Division), save_tempo);
                     d->m_DblRealTime = d->m_DblOldRealtime + delta_secs * 1600.0;
-                    d->m_RealTime = static_cast<quint64>(0.5 + d->m_DblRealTime);
+                    d->m_RealTime = quint64(0.5 + d->m_DblRealTime);
                     if (d->m_RevisedTime == d->m_TempoChangeTime)
                     {
                         d->m_OldCurrTime = d->m_RevisedTime;
@@ -270,9 +274,9 @@ void QSmf::readTrack()
                 else
                 {
                     delta_secs = ticksToSecs(d->m_RevisedTime - d->m_OldCurrTime,
-                            d->m_Division, d->m_CurrTempo);
+                            quint16(d->m_Division), d->m_CurrTempo);
                     d->m_DblRealTime = d->m_DblOldRealtime + delta_secs * 1600.0;
-                    d->m_RealTime = static_cast<quint64>(0.5 + d->m_DblRealTime);
+                    d->m_RealTime = quint64(0.5 + d->m_DblRealTime);
                 }
             }
         }
@@ -324,21 +328,21 @@ void QSmf::readTrack()
         {
         case meta_event:
             type = getByte();
-            lookfor = readVarLen();
+            lookfor = quint64(readVarLen());
             lookfor = d->m_ToBeRead - lookfor;
             msgInit();
-            while (d->m_ToBeRead > lookfor)
+            while ((d->m_ToBeRead > lookfor) && !endOfSmf())
             {
                 msgAdd(getByte());
             }
             metaEvent(type);
             break;
         case system_exclusive:
-            lookfor = readVarLen();
+            lookfor = quint64(readVarLen());
             lookfor = d->m_ToBeRead - lookfor;
             msgInit();
             msgAdd(system_exclusive);
-            while (d->m_ToBeRead > lookfor)
+            while ((d->m_ToBeRead > lookfor) && !endOfSmf())
             {
                 c = getByte();
                 msgAdd(c);
@@ -359,7 +363,7 @@ void QSmf::readTrack()
             {
                 msgInit();
             }
-            while (d->m_ToBeRead > lookfor)
+            while ((d->m_ToBeRead > lookfor) && !endOfSmf())
             {
                 c = getByte();
                 msgAdd(c);
@@ -377,6 +381,10 @@ void QSmf::readTrack()
             badByte(c, d->m_IOStream->device()->pos() - 1);
             break;
         }
+        if ((d->m_ToBeRead > lookfor) && endOfSmf())
+        {
+            SMFError("Unexpected end of input");
+        }
     }
     emit signalSMFTrackEnd();
 }
@@ -473,9 +481,9 @@ void QSmf::writeHeaderChunk(int format, int ntracks, int division)
 {
     write32bit(MThd);
     write32bit(6);
-    write16bit(format);
-    write16bit(ntracks);
-    write16bit(division);
+    write16bit(quint16(format));
+    write16bit(quint16(ntracks));
+    write16bit(quint16(division));
 }
 
 /**
@@ -536,7 +544,7 @@ void QSmf::writeMetaEvent(long deltaTime, int type, const QString& data)
     putByte(d->m_LastStatus = meta_event);
     putByte(type);
     QByteArray lcldata;
-    if (d->m_codec == NULL)
+    if (d->m_codec == nullptr)
         lcldata = data.toLatin1();
     else
         lcldata = d->m_codec->fromUnicode(data);
@@ -688,23 +696,23 @@ void QSmf::writeMidiEvent(long deltaTime, int type, long len, char* data)
 {
     unsigned int i, j, size;
     quint8 c;
-    writeVarLen(deltaTime);
+    writeVarLen(quint64(deltaTime));
     if ((type != system_exclusive) && (type != end_of_sysex))
     {
         SMFError("error: type should be system exclusive");
     }
     d->m_LastStatus = 0;
-    c = type;
+    c = quint8(type);
     putByte(c);
-    size = len;
-    c = (unsigned)data[0];
+    size = unsigned(len);
+    c = quint8(data[0]);
     if (c == type)
         --size;
     writeVarLen(size);
     j = (c == type ? 1 : 0);
-    for (i = j; i < (unsigned)len; ++i)
+    for (i = j; i < unsigned(len); ++i)
     {
-        putByte(data[i]);
+        putByte(quint8(data[i]));
     }
 }
 
@@ -779,11 +787,11 @@ void QSmf::writeTimeSignature(long deltaTime, int num, int den, int cc, int bb)
  */
 void QSmf::writeKeySignature(long deltaTime, int tone, int mode)
 {
-    writeVarLen(deltaTime);
+    writeVarLen(quint64(deltaTime));
     putByte(d->m_LastStatus = meta_event);
     putByte(key_signature);
     putByte(2);
-    putByte((char)tone);
+    putByte(quint8(tone));
     putByte(mode & 0x01);
 }
 
@@ -831,7 +839,7 @@ void QSmf::write16bit(quint16 data)
 quint16 QSmf::to16bit(quint8 c1, quint8 c2)
 {
     quint16 value;
-    value = (c1 << 8);
+    value = quint16(c1 << 8);
     value += c2;
     return value;
 }
@@ -839,9 +847,9 @@ quint16 QSmf::to16bit(quint8 c1, quint8 c2)
 quint32 QSmf::to32bit(quint8 c1, quint8 c2, quint8 c3, quint8 c4)
 {
     quint32 value;
-    value = (c1 << 24);
-    value += (c2 << 16);
-    value += (c3 << 8);
+    value = unsigned(c1 << 24);
+    value += unsigned(c2 << 16);
+    value += unsigned(c3 << 8);
     value += c4;
     return value;
 }
@@ -866,7 +874,7 @@ quint32 QSmf::read32bit()
 
 long QSmf::readVarLen()
 {
-    long value;
+    quint64 value;
     quint8 c;
 
     c = getByte();
@@ -880,7 +888,7 @@ long QSmf::readVarLen()
             value = (value << 7) + (c & 0x7f);
         } while ((c & 0x80) != 0);
     }
-    return value;
+    return long(value);
 }
 
 void QSmf::readExpected(const QString& s)
@@ -943,13 +951,13 @@ double QSmf::ticksToSecs(quint64 ticks, quint16 division, quint64 tempo)
 
     if (division > 0)
     {
-        result = static_cast<double>(ticks * tempo)/(division * 1000000.0);
+        result = double(ticks * tempo)/(division * 1000000.0);
     }
     else
     {
         smpte_format = upperByte(division);
         smpte_resolution = lowerByte(division);
-        result = static_cast<double>(ticks)/(smpte_format * smpte_resolution
+        result = double(ticks)/(smpte_format * smpte_resolution
                 * 1000000.0);
     }
     return result;
@@ -1023,7 +1031,7 @@ void QSmf::metaEvent(quint8 b)
     case marker:
     case cue_point: {
             QString s;
-            if (d->m_codec == NULL)
+            if (d->m_codec == nullptr)
                 s = QString(m);
             else
                 s = d->m_codec->toUnicode(m);
@@ -1194,7 +1202,7 @@ void QSmf::setFileFormat(int fileFormat)
  */
 long QSmf::getFilePos()
 {
-    return (long) d->m_IOStream->device()->pos();
+    return long(d->m_IOStream->device()->pos());
 }
 
 /**
