@@ -1,6 +1,6 @@
 /*
     WRK File component
-    Copyright (C) 2010-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2010-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,12 +12,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "qwrk.h"
 #include <cmath>
 #include <QDataStream>
 #include <QFile>
@@ -25,6 +23,7 @@
 #include <QTextStream>
 #include <QTextCodec>
 #include <QStringList>
+#include <drumstick/qwrk.h>
 
 /**
  * @file qwrk.cpp
@@ -555,7 +554,7 @@ QString QWrk::readString(int len)
     if ( len > 0 ) {
         quint8 c = 0xff;
         QByteArray data;
-        for ( int i = 0; i < len && c != 0; ++i ) {
+        for ( int i = 0; i < len && c != 0 && !atEnd(); ++i ) {
             c = readByte();
             if ( c != 0)
                 data += c;
@@ -581,7 +580,7 @@ QString QWrk::readVarString()
         b = readByte();
         if (b != 0)
             data += b;
-    } while (b != 0);
+    } while (b != 0 && !atEnd());
     if (d->m_codec == NULL)
         s = QString(data);
     else
@@ -730,12 +729,12 @@ void QWrk::processTimebaseChunk()
 void QWrk::processNoteArray(int track, int events)
 {
     quint32 time = 0;
-    quint8  status = 0, data1 = 0, data2 = 0;
+    quint8  status = 0, data1 = 0, data2 = 0, i = 0;
     quint16 dur = 0;
     int value = 0, type = 0, channel = 0, len = 0;
     QString text;
     QByteArray data;
-    for ( int i = 0; i < events; ++i ) {
+    for ( i = 0; (i < events) && !atEnd(); ++i ) {
         time = read24bit();
         status = readByte();
         dur = 0;
@@ -804,17 +803,20 @@ void QWrk::processNoteArray(int track, int events)
             Q_EMIT signalWRKText(track, time, status, text);
         }
     }
+    if ((i < events) && atEnd()) {
+        Q_EMIT signalWRKError("Corrupted file");
+    }
     Q_EMIT signalWRKStreamEnd(time + dur);
 }
 
 void QWrk::processStreamChunk()
 {
     long time = 0;
-    int dur = 0, value = 0, type = 0, channel = 0;
+    int dur = 0, value = 0, type = 0, channel = 0, i = 0;
     quint8 status = 0, data1 = 0, data2 = 0;
     quint16 track = read16bit();
     int events = read16bit();
-    for ( int i = 0; i < events; ++i ) {
+    for ( i = 0; (i < events) && !atEnd(); ++i ) {
         time = read24bit();
         status = readByte();
         data1 = readByte();
@@ -847,6 +849,9 @@ void QWrk::processStreamChunk()
                 break;
         }
     }
+    if ((i < events) && atEnd()) {
+        Q_EMIT signalWRKError("Corrupted file");
+    }
     Q_EMIT signalWRKStreamEnd(time + dur);
 }
 
@@ -1047,8 +1052,8 @@ void QWrk::processNewTrack()
 {
     qint16 bank = -1;
     qint16 patch = -1;
-    qint16 vol = -1;
-    qint16 pan = -1;
+    //qint16 vol = -1;
+    //qint16 pan = -1;
     qint8 key = -1;
     qint8 vel = 0;
     quint8 port = 0;
@@ -1061,8 +1066,8 @@ void QWrk::processNewTrack()
     QString name = readString(len);
     bank = read16bit();
     patch = read16bit();
-    vol = read16bit();
-    pan = read16bit();
+    /*vol =*/ read16bit();
+    /*pan =*/ read16bit();
     key = readByte();
     vel = readByte();
     readGap(7);
