@@ -1,6 +1,6 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2015 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef NETMIDIINPUT_H
@@ -23,12 +22,13 @@
 #include <QObject>
 #include <QHostAddress>
 #include <QtPlugin>
-#include "rtmidiinput.h"
+#include <drumstick/rtmidiinput.h>
 
 namespace drumstick {
 namespace rt {
 
-    const QString STR_ADDRESS(QLatin1Literal("225.0.0.37"));
+    const QString STR_ADDRESS_IPV4(QLatin1Literal("225.0.0.37"));
+    const QString STR_ADDRESS_IPV6(QLatin1Literal("ff12::37"));
     const int MULTICAST_PORT(21928);
     const int LAST_PORT(21948);
 
@@ -41,7 +41,7 @@ namespace rt {
         Q_INTERFACES(drumstick::rt::MIDIInput)
 
     public:
-        explicit NetMIDIInput(QObject *parent = 0);
+        explicit NetMIDIInput(QObject *parent = nullptr);
 
         // MIDIInput interface
     public:
