@@ -1,6 +1,6 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2015 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QFile>
@@ -210,8 +209,10 @@ void OSSOutput::sendChannelPressure(int chan, int value)
     d->sendMessage(MIDI_STATUS_CHANNELPRESSURE + chan, value);
 }
 
-void OSSOutput::sendPitchBend(int chan, int value)
+void OSSOutput::sendPitchBend(int chan, int v)
 {
+    // -8192 <= v <= 8191; 0 <= value <= 16384
+    int value = 8192 + v;
     d->sendMessage(MIDI_STATUS_PITCHBEND + chan, MIDI_LSB(value), MIDI_MSB(value));
 }
 
