@@ -1,6 +1,6 @@
 /*
     Drumstick RT Windows Backend
-    Copyright (C) 2009-2015 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QDebug>
@@ -22,7 +21,7 @@
 #include <QByteArray>
 #include <QVarLengthArray>
 #include <qmath.h>
-#include <windows.h>
+#include <Windows.h>
 #include <mmsystem.h>
 #include "winmidioutput.h"
 
@@ -55,7 +54,7 @@ namespace rt {
         QStringList m_excludedNames;
 
         WinMIDIOutputPrivate():
-            m_handle(0),
+            m_handle(nullptr),
             m_clientFilter(true),
             m_publicName(DEFAULT_PUBLIC_NAME)
         {
@@ -124,7 +123,7 @@ namespace rt {
             MMRESULT res;
             int dev = -1;
 
-            if (m_handle != 0)
+            if (m_handle != nullptr)
                 close();
             reloadDeviceList(!m_clientFilter);
             dev = deviceIndex(name);
@@ -140,7 +139,7 @@ namespace rt {
         void close()
         {
             MMRESULT res;
-            if (m_handle != 0) {
+            if (m_handle != nullptr) {
                 res = midiOutReset( m_handle );
                 if (res != MMSYSERR_NOERROR)
                     qDebug() << "midiOutReset() err:" << mmErrorString(res);
@@ -149,7 +148,7 @@ namespace rt {
                     m_currentOutput.clear();
                 else
                     qDebug() << "midiStreamClose() err:" << mmErrorString(res);
-                m_handle = 0;
+                m_handle = nullptr;
             }
         }
 
@@ -340,9 +339,11 @@ namespace rt {
         d->sendShortMessage(packet);
     }
 
-    void WinMIDIOutput::sendPitchBend(int chan, int value)
+    void WinMIDIOutput::sendPitchBend(int chan, int v)
     {
         WinMIDIPacket packet;
+        // -8192 <= v <= 8191; 0 <= value <= 16384
+        int value = 8192 + v;
         packet.data[0] = MIDI_STATUS_PITCHBEND | (chan & MIDI_CHANNEL_MASK);
         packet.data[1] = MIDI_LSB(value);
         packet.data[2] = MIDI_MSB(value);
