@@ -1,6 +1,6 @@
 /*
     Drumstick RT Windows Backend
-    Copyright (C) 2009-2015 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,18 +12,17 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef WINMIDIOUTPUT_H
 #define WINMIDIOUTPUT_H
 
 #include <QObject>
-#include <windows.h>
+#include <Windows.h>
 #include <mmsystem.h>
-#include "rtmidioutput.h"
+#include <drumstick/rtmidioutput.h>
 
 namespace drumstick {
 namespace rt {
@@ -39,7 +38,7 @@ namespace rt {
     public:
         class WinMIDIOutputPrivate;
 
-        explicit WinMIDIOutput(QObject *parent = 0);
+        explicit WinMIDIOutput(QObject *parent = nullptr);
         virtual ~WinMIDIOutput();
 
         // MIDIOutput interface
