@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,26 +12,24 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "drumgrid.h"
-#include "drumgridmodel.h"
-#include "ui_drumgrid.h"
-#include "drumgridabout.h"
-
 #include <QInputDialog>
 #include <QShortcut>
 #include <QToolTip>
 #include <QSignalMapper>
 #include <QSettings>
 #include <qmath.h>
-#include "alsaclient.h"
-#include "alsaport.h"
-#include "alsaqueue.h"
-#include "alsaevent.h"
+#include <drumstick/alsaclient.h>
+#include <drumstick/alsaport.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaevent.h>
+#include "drumgrid.h"
+#include "drumgridmodel.h"
+#include "ui_drumgrid.h"
+#include "drumgridabout.h"
 
 DrumGrid::DrumGrid(QWidget *parent)
     : QMainWindow(parent),
