@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,14 +12,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "dumpmid.h"
-#include "cmdlineargs.h"
-
 #include <signal.h>
 #include <QObject>
 #include <QString>
@@ -28,6 +24,13 @@
 #include <QtDebug>
 #include <QReadLocker>
 #include <QWriteLocker>
+#include <QCommandLineParser>
+
+#include "dumpmid.h"
+#include "cmdversion.h"
+
+const QString PGM_NAME("drumstick-dumpmid");
+const QString PGM_DESCRIPTION("Drumstick command line utility for decoding MIDI events");
 
 static QTextStream cout(stdout, QIODevice::WriteOnly);
 static QTextStream cerr(stderr, QIODevice::WriteOnly);
@@ -453,17 +456,33 @@ int main(int argc, char **argv)
         "or the kernel module (snd_seq) is not loaded. "
         "Please check your ALSA/MIDI configuration.";
 
-    CmdLineArgs args;
-    args.setUsage("[port]");
-    args.addOptionalArgument("port", "Source MIDI port");
-    args.parse(argc, argv);
+    QCoreApplication app(argc, argv);
+    QCoreApplication::setApplicationName(PGM_NAME);
+    QCoreApplication::setApplicationVersion(PGM_VERSION);
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(PGM_DESCRIPTION);
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
+    QCommandLineOption portOption({"p", "port"}, "Source MIDI Port.", "client:port");
+    parser.addOption(portOption);
+    parser.process(app);
+
+    if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
+        return 0;
+    }
+
     try {
         test = new QDumpMIDI();
         signal(SIGINT, signalHandler);
         signal(SIGTERM, signalHandler);
-        QVariant portName = args.getArgument("port");
-        if (!portName.isNull())
-            test->subscribe(portName.toString());
+        if (parser.isSet(portOption)) {
+            QString portName = parser.value(portOption);
+            test->subscribe(portName);
+        } else {
+            cerr << "Port argument is mandatory" << endl;
+            parser.showHelp();
+        }
         test->run();
     } catch (const SequencerError& ex) {
         cerr << errorstr + " Returned error was: " + ex.qstrError() << endl;
