@@ -1,6 +1,6 @@
 /*
     Standard MIDI File dump program
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -14,26 +14,29 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "dumpsmf.h"
-#include "qsmf.h"
-#include "cmdlineargs.h"
-
 #include <cstdlib>
 #include <QObject>
 #include <QString>
 #include <QCoreApplication>
 #include <QTextStream>
 #include <QTextCodec>
+#include <QFileInfo>
+#include <QCommandLineParser>
+#include <drumstick/qsmf.h>
+#include "cmdversion.h"
+#include "dumpsmf.h"
 
+const QString PGM_NAME("drumstick-dumpsmf");
+const QString PGM_DESCRIPTION("Drumstick command line utility for decoding SMF (Standard MIDI) files");
 static QTextStream cout(stdout, QIODevice::WriteOnly);
+static QTextStream cerr(stderr, QIODevice::WriteOnly);
 
 QSpySMF::QSpySMF():
-    m_currentTrack(0)
+    m_currentTrack(0), m_engine(nullptr), m_rc(0)
 {
     QTextCodec *codec = QTextCodec::codecForName("UTF-8");
     m_engine = new QSmf(this);
@@ -223,26 +226,60 @@ void QSpySMF::tempoEvent(int tempo)
 
 void QSpySMF::errorHandler(const QString& errorStr)
 {
-    cout << "*** Warning! " << errorStr
+    m_rc++;
+    cerr << "*** Warning! " << errorStr
          << " at file offset " << m_engine->getFilePos()
          << endl;
 }
 
 void QSpySMF::run(QString fileName)
 {
+    m_currentTrack = 0;
     cout << "__ticks __seconds ch event__________ data____" << endl;
     m_engine->readFromFile(fileName);
 }
 
+int QSpySMF::numErrors()
+{
+    return m_rc;
+}
+
 int main(int argc, char **argv)
 {
     QSpySMF spy;
-    CmdLineArgs args;
-    args.setUsage("file");
-    args.addRequiredArgument("file", "Input SMF name");
-    args.parse(argc, argv);
-    QVariant file = args.getArgument("file");
-    if (!file.isNull())
-        spy.run(file.toString());
+    QString file;
+    QCoreApplication app(argc, argv);
+    QCoreApplication::setApplicationName(PGM_NAME);
+    QCoreApplication::setApplicationVersion(PGM_VERSION);
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(PGM_DESCRIPTION);
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
+    parser.addPositionalArgument("file", "Input SMF file name.", "files...");
+    parser.process(app);
+
+    if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
+        return 0;
+    }
+
+    QStringList fileNames, positionalArgs = parser.positionalArguments();
+    if (positionalArgs.isEmpty()) {
+        cerr << "Input file name(s) missing" << endl;
+        parser.showHelp();
+    }
+
+    foreach(const QString& a, positionalArgs) {
+        QFileInfo f(a);
+        if (f.exists())
+            fileNames += f.canonicalFilePath();
+        else
+            cerr << "File not found: " << a << endl;
+    }
+
+    foreach(const QString& file, fileNames) {
+        spy.run(file);
+    }
+    return spy.numErrors();
 }
 
