@@ -1,6 +1,6 @@
 /*
     Standard MIDI File dump program
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -14,12 +14,11 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "qsmf.h"
+#include <drumstick/qsmf.h>
 
 using namespace drumstick;
 
@@ -32,6 +31,7 @@ using namespace drumstick;
     void run(QString fileName);
     void dump(const QString& chan, const QString& event, const QString& data);
     void dumpStr(const QString& event, const QString& data);
+    int  numErrors();
 
   public slots:
     void headerEvent(int format, int ntrks, int division);
@@ -62,4 +62,5 @@ using namespace drumstick;
   private:
     int m_currentTrack;
     QSmf *m_engine;
+    int m_rc;
   };
