@@ -1,6 +1,6 @@
 /*
     Cakewalk WRK file dump program
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -14,12 +14,11 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "qwrk.h"
+#include <drumstick/qwrk.h>
 
 using namespace drumstick;
 
@@ -38,6 +37,7 @@ using namespace drumstick;
     void dumpVar(const QString& name, unsigned int value);
     void setVerbosity(bool enable);
     bool verbosityEnabled() const;
+    int returnCode() const { return m_rc; }
 
   public slots:
     void unknownChunk(int type, const QByteArray& data);
@@ -87,4 +87,5 @@ using namespace drumstick;
   private:
     bool m_verbosity;
     QWrk *m_engine;
+    int m_rc;
   };
