@@ -1,6 +1,6 @@
 /*
     SMF GUI Player test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef INCLUDED_GUIPLAYER_H
@@ -64,7 +63,7 @@ class GUIPlayer : public QMainWindow
     Q_OBJECT
 
 public:
-    GUIPlayer(QWidget *parent = 0, Qt::WindowFlags flags = 0);
+    GUIPlayer(QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr);
     ~GUIPlayer();
 
     void appendSMFEvent(SequencerEvent* ev);
@@ -77,7 +76,7 @@ public:
     void dragEnterEvent(QDragEnterEvent* event);
     void dropEvent(QDropEvent* event);
     void closeEvent(QCloseEvent* event);
-    bool event(QEvent* event);
+    //bool event(QEvent* event);
     void openFile(const QString& fileName);
     void readSettings();
     void writeSettings();
@@ -98,7 +97,6 @@ public slots:
     void tempoReset();
     void volumeReset();
     void tempoSlider(int value);
-    void quit();
     void volumeSlider(int value);
     void pitchShift(int value);
     void songFinished();
