@@ -1,6 +1,6 @@
 /*
     Standard MIDI simple metronome
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
  
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,24 +12,23 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
  
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef METRONOME_H
 #define METRONOME_H
 
-#include "alsaevent.h"
-#include "alsaclient.h"
-#include "alsaqueue.h"
-#include "alsaport.h"
-
 #include <QObject>
 #include <QString>
 #include <QList>
 #include <QReadWriteLock>
 
+#include <drumstick/alsaevent.h>
+#include <drumstick/alsaclient.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaport.h>
+
 const int TEMPO_DEFAULT(120);
 const int NOTE_DURATION(10);
 const int RHYTHM_TS_NUM(4);
@@ -57,8 +56,6 @@ public:
     void stop();
     void subscribe(const QString& portName);
     void shutupSound();
-    //void usage();
-    //void info();
 
     void sendControlChange( int cc, int value );
     void sendInitialControls();
