@@ -1,6 +1,6 @@
 /*
     Standard MIDI File player program 
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
  
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
  
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef PLAYSMF_H_
@@ -25,11 +24,11 @@
 #include <QList>
 #include <QReadWriteLock>
 
-#include "qsmf.h"
-#include "alsaevent.h"
-#include "alsaclient.h"
-#include "alsaqueue.h"
-#include "alsaport.h"
+#include <drumstick/qsmf.h>
+#include <drumstick/alsaevent.h>
+#include <drumstick/alsaclient.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaport.h>
 
 using namespace drumstick;
 
@@ -56,8 +55,6 @@ public:
     void dump(const QString& chan, const QString& event, const QString& data);
     void dumpStr(const QString& event, const QString& data);
     void shutupSound();
-    //void usage();
-    //void info();
 
 public slots:
     void headerEvent(int format, int ntrks, int division);
@@ -75,16 +72,6 @@ public slots:
     void keySigEvent(int b0, int b1);
     void errorHandler(const QString& errorStr);
 
-//  void trackStartEvent();
-//  void trackEndEvent();
-//  void endOfTrackEvent();
-//  void variableEvent(const QByteArray& data);
-//  void metaMiscEvent(int typ, const QByteArray& data);
-//  void seqNum(int seq);
-//  void forcedChannel(int channel);
-//  void forcedPort(int port);
-//  void smpteEvent(int b0, int b1, int b2, int b3, int b4);
-
 private:
     int m_division;
     int m_portId;
