@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ Library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
  
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef STABLEHEADERS_H_
