@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library 
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,20 +12,24 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
  
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "alsatimer.h"
-#include "alsaqueue.h"
-#include "alsaclient.h"
-#include "subscription.h"
-#include "cmdlineargs.h"
 #include <QTextStream>
 #include <QStringList>
+#include <QCommandLineParser>
 
-static QTextStream cout(stdout, QIODevice::WriteOnly); 
+#include <drumstick/alsatimer.h>
+#include <drumstick/alsaqueue.h>
+#include <drumstick/alsaclient.h>
+#include <drumstick/subscription.h>
+
+#include "cmdversion.h"
+
+const QString PGM_NAME("drumstick-sysinfo");
+const QString PGM_DESCRIPTION("ALSA Sequencer System Info");
+static QTextStream cout(stdout, QIODevice::WriteOnly);
 static QTextStream cerr(stderr, QIODevice::WriteOnly);
 
 using namespace drumstick;
@@ -72,7 +76,7 @@ void queryQueues(MidiClient* c)
     QList<int> queues = c->getAvailableQueues();
     foreach( int q, queues ) {
         MidiQueue* queue = new MidiQueue(c, q);
-        if (queue != NULL) {
+        if (queue != nullptr) {
             QueueInfo qinfo = queue->getInfo();
             QueueStatus qsts = queue->getStatus();
             QueueTempo qtmp = queue->getTempo();
@@ -154,8 +158,8 @@ QString subsNames(SubscribersList& subs)
 {
     QStringList lst;
     foreach( Subscriber s, subs ) {
-        QString sname = QString("%1:%2").arg((int)s.getAddr()->client)
-                                        .arg((int)s.getAddr()->port);
+        QString sname = QString("%1:%2").arg(static_cast<int>(s.getAddr()->client))
+                                        .arg(static_cast<int>(s.getAddr()->port));
         lst << sname;
     }
     return lst.join(", ");
@@ -186,14 +190,13 @@ void queryClients(MidiClient* c)
     }
 }
 
-void systemInfo(CmdLineArgs* args)
+void systemInfo()
 {
     MidiClient* client = new MidiClient();
     client->open();
-    client->setClientName(args->programName());
+    client->setClientName(PGM_NAME);
     SystemInfo info = client->getSystemInfo();
-    cout << "ALSA Sequencer System Info, version: "
-         << args->programVersion() << endl;
+    cout << PGM_DESCRIPTION << ", version: "<< PGM_VERSION << endl;
     cout << "Compiled ALSA library: " << LIBRARY_VERSION << endl;
     cout << "Runtime ALSA library: "
          << getRuntimeALSALibraryVersion() << endl;
@@ -226,10 +229,22 @@ int main(int argc, char **argv)
         "or the device node (/dev/snd/seq) doesn't exists, "
         "or the kernel module (snd_seq) is not loaded. "
         "Please check your ALSA/MIDI configuration.";
-    CmdLineArgs args;
-    args.parse(argc, argv);
+    QCoreApplication app(argc, argv);
+    QCoreApplication::setApplicationName(PGM_NAME);
+    QCoreApplication::setApplicationVersion(PGM_VERSION);
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(PGM_DESCRIPTION);
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
+    parser.process(app);
+
+    if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
+        return 0;
+    }
+
     try {
-        systemInfo(&args);
+        systemInfo();
     } catch (const SequencerError& ex) {
         cerr << errorstr + " Returned error was: " + ex.qstrError() << endl;
     } catch (...) {
