@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library 
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,14 +12,15 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "connections.h"
 #include "networksettingsdialog.h"
 #include "fluidsettingsdialog.h"
+#include "sonivoxsettingsdialog.h"
+#include "macsynthsettingsdialog.h"
 
 Connections::Connections(QWidget *parent)
     : QDialog(parent),
@@ -127,7 +128,10 @@ void Connections::refreshInputs(QString id)
 
 void Connections::refreshOutputs(QString id)
 {
-    ui.btnOutputDriverCfg->setEnabled(id == "Network" || id == "FluidSynth");
+    ui.btnOutputDriverCfg->setEnabled(id == "Network" ||
+                                      id == "FluidSynth" ||
+                                      id == "DLS Synth" ||
+                                      id == "SonivoxEAS");
     if (m_midiOut != 0 && m_midiOut->backendName() != id) {
         m_midiOut->close();
         int idx = ui.m_outputBackends->findText(id, Qt::MatchStartsWith);
@@ -190,5 +194,11 @@ void Connections::configureOutputDriver()
     } else if (driver == "FluidSynth") {
         FluidSettingsDialog dlg(this);
         m_settingsChanged |= (dlg.exec() == QDialog::Accepted);
+    } else if (driver == "SonivoxEAS") {
+        SonivoxSettingsDialog dlg(this);
+        m_settingsChanged |= (dlg.exec() == QDialog::Accepted);
+    } else if (driver == "DLS Synth") {
+        MacSynthSettingsDialog dlg(this);
+        m_settingsChanged |= (dlg.exec() == QDialog::Accepted);
     }
 }
