@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef NETWORKSETTINGSDIALOG_H
@@ -32,7 +31,7 @@ class NetworkSettingsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit NetworkSettingsDialog(QWidget *parent = 0);
+    explicit NetworkSettingsDialog(QWidget *parent = nullptr);
     ~NetworkSettingsDialog();
     void readSettings();
     void writeSettings();
@@ -41,6 +40,7 @@ public slots:
     void accept();
     void showEvent(QShowEvent *event);
     void restoreDefaults();
+    void toggledIPv6(bool checked);
 
 private:
     Ui::NetworkSettingsDialog *ui;
