@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,29 +12,33 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QDebug>
+#include <drumstick/backendmanager.h>
 #include "vpiano.h"
-#include "backendmanager.h"
 
 VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     : QMainWindow(parent, flags),
-    m_midiIn(0),
-    m_midiOut(0)
+    m_midiIn(nullptr),
+    m_midiOut(nullptr)
 {
-    QString nativeBackend;
+    m_nativeInput = QLatin1Literal("Network");
+    m_defaultInput = QLatin1Literal("21928");
 #if defined(Q_OS_LINUX)
-    nativeBackend = QLatin1Literal("ALSA");
+    m_nativeOutput = QLatin1Literal("SonivoxEAS");
+    m_defaultOutput = QLatin1Literal("SonivoxEAS");
 #elif defined(Q_OS_OSX)
-    nativeBackend = QLatin1Literal("CoreMIDI");
+    m_nativeOutput = QLatin1Literal("DLS Synth");
+    m_defaultOutput = QLatin1Literal("DLS Synth");
 #elif defined(Q_OS_WIN)
-    nativeBackend = QLatin1Literal("Windows MM");
+    m_nativeOutput = QLatin1Literal("Windows MM");
+    m_defaultOutput = QLatin1Literal("Microsoft GS Wavetable Synth");
 #else
-    nativeBackend = QLatin1Literal("Network");
+    m_nativeOutput = m_nativeInput;
+    m_defaultOutput = m_defaultInput;
 #endif
 
     ui.setupUi(this);
@@ -49,16 +53,22 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     QList<MIDIOutput*> outputs = man.availableOutputs();
 
     findInput(m_lastInputBackend, inputs);
-    if (m_midiIn == 0) {
-        findInput(nativeBackend, inputs);
+    if (m_midiIn == nullptr) {
+        findInput(m_nativeInput, inputs);
+        if (m_midiIn == nullptr) {
+            qFatal("Unable to find a suitable input backend.");
+        }
     }
 
     findOutput(m_lastOutputBackend, outputs);
-    if (m_midiOut == 0) {
-        findOutput(nativeBackend, outputs);
+    if (m_midiOut == nullptr) {
+        findOutput(m_nativeOutput, outputs);
+        if (m_midiOut == nullptr) {
+            qFatal("Unable to find a suitable output backend");
+        }
     }
 
-    connect(ui.actionExit, SIGNAL(triggered()), qApp, SLOT(quit()));
+    connect(ui.actionExit, SIGNAL(triggered()), SLOT(close()));
     connect(ui.actionAbout, SIGNAL(triggered()), SLOT(slotAbout()));
     connect(ui.actionAbout_Qt, SIGNAL(triggered()), SLOT(slotAboutQt()));
     connect(ui.actionConnections, SIGNAL(triggered()), SLOT(slotConnections()));
@@ -73,28 +83,44 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     dlgConnections.setMidiThru(m_midiThru);
     dlgConnections.setAdvanced(m_advanced);
 
-    if (m_midiIn != 0) {
-        connect(m_midiIn, SIGNAL(midiNoteOn(int,int,int)), SLOT(slotNoteOn(int,int,int)));
-        connect(m_midiIn, SIGNAL(midiNoteOff(int,int,int)), SLOT(slotNoteOff(int,int,int)));
+    if (m_midiIn != nullptr) {
+#if QT_VERSION < 0x050700
+        connect(m_midiIn, SIGNAL(midiNoteOn(int,int,int)),
+                          SLOT(slotNoteOn(int,int,int)),
+                          Qt::QueuedConnection);
+        connect(m_midiIn, SIGNAL(midiNoteOff(int,int,int)),
+                          SLOT(slotNoteOff(int,int,int)),
+                          Qt::QueuedConnection);
+#else
+        connect(m_midiIn, &MIDIInput::midiNoteOn,
+                this, QOverload<int,int,int>::of(&VPiano::slotNoteOn),
+                Qt::QueuedConnection);
+        connect(m_midiIn, &MIDIInput::midiNoteOff,
+                this, QOverload<int,int,int>::of(&VPiano::slotNoteOff),
+                Qt::QueuedConnection);
+#endif
         if (!m_lastInputConnection.isEmpty()) {
             m_midiIn->initialize(&settings);
             m_midiIn->open(m_lastInputConnection);
         }
     }
 
-    if (m_midiOut != 0 && !m_lastOutputConnection.isEmpty()) {
+    if (m_midiOut != nullptr && !m_lastOutputConnection.isEmpty()) {
         m_midiOut->initialize(&settings);
         m_midiOut->open(m_lastOutputConnection);
-        m_midiIn->setMIDIThruDevice(m_midiOut);
-        m_midiIn->enableMIDIThru(m_midiThru);
+        if (m_midiIn != nullptr) {
+            m_midiIn->setMIDIThruDevice(m_midiOut);
+            m_midiIn->enableMIDIThru(m_midiThru);
+        }
     }
 }
 
 VPiano::~VPiano()
 {
+    //qDebug() << Q_FUNC_INFO;
     m_midiIn->close();
     m_midiOut->close();
-    qDebug() << "Cheers!";
+    //qDebug() << "Cheers!";
 }
 
 void VPiano::slotNoteOn(const int midiNote, const int vel)
@@ -111,7 +137,6 @@ void VPiano::slotNoteOff(const int midiNote, const int vel)
 
 void VPiano::slotNoteOn(const int chan, const int note, const int vel)
 {
-    //Q_UNUSED(vel)
     if (dlgPreferences.getInChannel() == chan) {
         if (vel > 0)
             ui.pianokeybd->getPianoScene()->showNoteOn(note);
@@ -142,15 +167,15 @@ void VPiano::slotConnections()
 {
     dlgConnections.refresh();
     if (dlgConnections.exec() == QDialog::Accepted) {
-        if (m_midiIn != 0) {
+        if (m_midiIn != nullptr) {
             m_midiIn->disconnect();
         }
-        if (m_midiOut != 0) {
+        if (m_midiOut != nullptr) {
             m_midiOut->disconnect();
         }
         m_midiIn = dlgConnections.getInput();
         m_midiOut = dlgConnections.getOutput();
-        if (m_midiIn != 0) {
+        if (m_midiIn != nullptr) {
             connect(m_midiIn, SIGNAL(midiNoteOn(int,int,int)), SLOT(slotNoteOn(int,int,int)));
             connect(m_midiIn, SIGNAL(midiNoteOff(int,int,int)), SLOT(slotNoteOff(int,int,int)));
         }
@@ -176,6 +201,7 @@ void VPiano::slotPreferences()
 
 void VPiano::closeEvent(QCloseEvent *event)
 {
+    //qDebug() << Q_FUNC_INFO;
     writeSettings();
     event->accept();
 }
@@ -192,7 +218,7 @@ void VPiano::writeSettings()
     settings.beginGroup("Connections");
     settings.setValue("inputBackend", m_midiIn->backendName());
     settings.setValue("outputBackend", m_midiOut->backendName());
-    settings.setValue("inputConenction", m_midiIn->currentConnection());
+    settings.setValue("inputConnection", m_midiIn->currentConnection());
     settings.setValue("outputConnection", m_midiOut->currentConnection());
     settings.setValue("midiThru", m_midiThru);
     settings.setValue("advanced", m_advanced);
@@ -220,10 +246,10 @@ void VPiano::readSettings()
     settings.endGroup();
 
     settings.beginGroup("Connections");
-    m_lastInputBackend = settings.value("inputBackend").toString();
-    m_lastOutputBackend = settings.value("outputBackend").toString();
-    m_lastInputConnection = settings.value("inputConenction").toString();
-    m_lastOutputConnection = settings.value("outputConnection").toString();
+    m_lastInputBackend = settings.value("inputBackend", m_nativeInput).toString();
+    m_lastOutputBackend = settings.value("outputBackend", m_nativeOutput).toString();
+    m_lastInputConnection = settings.value("inputConnection", m_defaultInput).toString();
+    m_lastOutputConnection = settings.value("outputConnection", m_defaultOutput).toString();
     m_midiThru = settings.value("midiThru", false).toBool();
     m_advanced = settings.value("advanced", false).toBool();
     settings.endGroup();
@@ -242,20 +268,32 @@ void VPiano::readSettings()
 
 void VPiano::findInput(QString name, QList<MIDIInput *> &inputs)
 {
+    if (name.isEmpty()) {
+        return;
+    }
     foreach(MIDIInput* input, inputs) {
-        if (m_midiIn == 0 && (input->backendName() == name))  {
+        if (m_midiIn == nullptr && (input->backendName() == name))  {
             m_midiIn = input;
             break;
         }
     }
+    if (m_midiIn == nullptr) {
+        qWarning() << "Input backend not found: " << name;
+    }
 }
 
 void VPiano::findOutput(QString name, QList<MIDIOutput *> &outputs)
 {
+    if (name.isEmpty()) {
+        return;
+    }
     foreach(MIDIOutput* output, outputs) {
-        if (m_midiOut == 0 && (output->backendName() == name))  {
+        if (m_midiOut == nullptr && (output->backendName() == name))  {
             m_midiOut = output;
             break;
         }
     }
+    if (m_midiOut == nullptr) {
+        qWarning() << "Output backend not found: " << name;
+    }
 }
