@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef VPIANO_H
@@ -22,15 +21,14 @@
 
 #include <QMainWindow>
 #include <QCloseEvent>
+#include <drumstick/rtmidiinput.h>
+#include <drumstick/rtmidioutput.h>
 
 #include "ui_vpiano.h"
 #include "vpianoabout.h"
 #include "connections.h"
 #include "preferences.h"
 
-#include "rtmidiinput.h"
-#include "rtmidioutput.h"
-
 using namespace drumstick::rt;
 
 class VPiano : public QMainWindow
@@ -70,6 +68,10 @@ private:
     About dlgAbout;
     Connections dlgConnections;
     Preferences dlgPreferences;
+    QString m_nativeInput;
+    QString m_nativeOutput;
+    QString m_defaultInput;
+    QString m_defaultOutput;
 };
 
 #endif // VPIANO_H
