@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library 
-    Copyright (C) 2006-2015, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,40 +12,44 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along 
-    with this program; if not, write to the Free Software Foundation, Inc., 
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.    
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QApplication>
 #include <QFileInfo>
 #include <QSettings>
 #include <QTextStream>
-#include "cmdlineargs.h"
+#include <QCommandLineParser>
+#include <drumstick/backendmanager.h>
+
+#include "cmdversion.h"
 #include "vpiano.h"
-#include "backendmanager.h"
+
+const QString PGM_DESCRIPTION("Drumstick Simple Virtual Piano");
 
 int main(int argc, char *argv[])
 {
-    QTextStream cout(stdout, QIODevice::WriteOnly);
     QTextStream cerr(stderr, QIODevice::WriteOnly);
     QCoreApplication::setOrganizationName("drumstick.sourceforge.net");
     QCoreApplication::setOrganizationDomain("drumstick.sourceforge.net");
     QCoreApplication::setApplicationName("VPiano");
+    QCoreApplication::setApplicationVersion(PGM_VERSION);
     QApplication app(argc, argv);
 
-    CmdLineArgs args;
-    args.setStdQtArgs(true);
-    args.parse(argc, argv);
-
-    QFileInfo exeInfo(app.applicationFilePath());
-    cout << "program=" << exeInfo.fileName() << endl;
+    QCommandLineParser parser;
+    parser.setApplicationDescription(PGM_DESCRIPTION);
+    auto helpOption = parser.addHelpOption();
+    auto versionOption = parser.addVersionOption();
+    parser.process(app);
+    if (parser.isSet(versionOption) || parser.isSet(helpOption)) {
+        return 0;
+    }
 
     QSettings settings;
     settings.beginGroup(QSTR_DRUMSTICKRT_GROUP);
     settings.setValue(QSTR_DRUMSTICKRT_PUBLICNAMEIN, QLatin1String("Virtual Piano IN"));
     settings.setValue(QSTR_DRUMSTICKRT_PUBLICNAMEOUT, QLatin1String("Virtual Piano OUT"));
-    //settings.setValue(QSTR_DRUMSTICKRT_PATH, backendir);
     settings.endGroup();
     settings.sync();
 
